@@ -227,6 +227,7 @@ static inline uid_t __kuid_val(uid_t uid)
 #endif
 
 #include <linux/fb.h>               /* fb_info struct                   */
+#include <linux/screen_info.h>      /* screen_info                      */
 
 #if !defined(CONFIG_PCI)
 #warning "Attempting to build driver for a platform with no PCI support!"
@@ -1689,23 +1690,12 @@ extern NvBool nv_ats_supported;
  * and any other baggage we want to carry along
  *
  */
-#define NV_MAXNUM_DISPLAY_DEVICES 8
-
-typedef struct
-{
-    acpi_handle dev_handle;
-    int dev_id;
-} nv_video_t;
-
 typedef struct
 {
     nvidia_stack_t *sp;
     struct acpi_device *device;
-
-    nv_video_t pNvVideo[NV_MAXNUM_DISPLAY_DEVICES];
-
+    struct acpi_handle *handle;
     int notify_handler_installed;
-    int default_display_mask;
 } nv_acpi_t;
 
 #endif
@@ -2034,6 +2024,19 @@ static inline void nv_mutex_destroy(struct mutex *lock)
     mutex_destroy(lock);
 }
 
+#if LINUX_VERSION_CODE < KERNEL_VERSION(6, 3, 0)
+// Rel. commit "mm: introduce vma->vm_flags wrapper functions" (Suren Baghdasaryan, 26 Jan 2023)
+static inline void vm_flags_set(struct vm_area_struct *vma, vm_flags_t flags)
+{
+    vma->vm_flags |= flags;
+}
+
+static inline void vm_flags_clear(struct vm_area_struct *vma, vm_flags_t flags)
+{
+    vma->vm_flags &= ~flags;
+}
+#endif
+
 static inline NvBool nv_platform_supports_numa(nv_linux_state_t *nvl)
 {
     return nvl->numa_info.node_id != NUMA_NO_NODE;
